@@ -1,5 +1,5 @@
 /*
- * $Id: com-config.c,v 1.6.2.2 2002/04/04 10:00:07 mt Exp $
+ * $Id: com-config.c,v 1.7 2002/05/02 12:57:10 mt Exp $
  *
  * Common functions for configuration reading
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: com-config.c,v 1.6.2.2 2002/04/04 10:00:07 mt Exp $";
+static char rcsid[] = "$Id: com-config.c,v 1.7 2002/05/02 12:57:10 mt Exp $";
 #endif
 
 #include <config.h>
@@ -1012,6 +1012,9 @@ gid_t config_gid(char *snam, char *name, gid_t dflt)
 
 /* ------------------------------------------------------------
  * $Log: com-config.c,v $
+ * Revision 1.7  2002/05/02 12:57:10  mt
+ * merged with v1.8.2.2
+ *
  * Revision 1.6.2.2  2002/04/04 10:00:07  mt
  * fixed bug done while last changes
  *
