@@ -1,5 +1,5 @@
 /*
- * $Id: com-misc.c,v 1.9 2002/05/02 12:59:00 mt Exp $
+ * $Id: com-misc.c,v 1.9.2.1 2003/05/07 11:15:05 mt Exp $
  *
  * Common miscellaneous functions
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: com-misc.c,v 1.9 2002/05/02 12:59:00 mt Exp $";
+static char rcsid[] = "$Id: com-misc.c,v 1.9.2.1 2003/05/07 11:15:05 mt Exp $";
 #endif
 
 #include <config.h>
@@ -290,10 +290,10 @@ char *misc_strdup(char *file, int line, char *str)
 	int   len;
 
 	/* Basic sanity check	*/
-	len = 0;
-	if (str == NULL || (len = strlen(str)) == 0)
+	if (str == NULL)
 		misc_die(file, line, "misc_strdup: ?str?");
 
+	len = strlen(str);
 	ptr = (char *) misc_alloc(file, line, len + 1);
 	strncpy(ptr, str, len);
 
@@ -773,7 +773,9 @@ int misc_rand (int lrng, int urng)
 	if (lrng == urng) return lrng; 
 	if (lrng > urng) {
 		/* swap values */
-		lrng ^= urng ^= lrng ^= urng;
+		lrng ^= urng;
+		urng ^= lrng;
+		lrng ^= urng;
 	}
 
 	gettimeofday (&t, NULL); 
@@ -784,6 +786,10 @@ int misc_rand (int lrng, int urng)
 
 /* ------------------------------------------------------------
  * $Log: com-misc.c,v $
+ * Revision 1.9.2.1  2003/05/07 11:15:05  mt
+ * misc_strdup: changed to allow empty strings
+ * misc_rand: removed sequence in lrng/urng swapping
+ *
  * Revision 1.9  2002/05/02 12:59:00  mt
  * merged with v1.8.2.2
  *
