@@ -1,5 +1,5 @@
 /*
- * $Id: com-socket.c,v 1.7.2.1 2003/05/07 11:14:08 mt Exp $
+ * $Id: com-socket.c,v 1.7.2.2 2005/01/10 11:37:36 mt Exp $
  *
  * Common functions for TCP/IP sockets
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: com-socket.c,v 1.7.2.1 2003/05/07 11:14:08 mt Exp $";
+static char rcsid[] = "$Id: com-socket.c,v 1.7.2.2 2005/01/10 11:37:36 mt Exp $";
 #endif
 
 #include <config.h>
@@ -84,6 +84,9 @@ static char rcsid[] = "$Id: com-socket.c,v 1.7.2.1 2003/05/07 11:14:08 mt Exp $"
 #if defined(HAVE_STROPTS_H)
 #   include <stropts.h>
 #endif
+#if defined(HAVE_SYS_PARAM_H)
+#   include <sys/param.h>
+#endif
 #if defined(HAVE_SYS_CONF_H)
 #   include <sys/conf.h>
 #endif
@@ -2272,6 +2275,9 @@ int getfqdomainname(char *fqdomain, size_t n)
 
 /* ------------------------------------------------------------
  * $Log: com-socket.c,v $
+ * Revision 1.7.2.2  2005/01/10 11:37:36  mt
+ * added sys/param.h inclusion
+ *
  * Revision 1.7.2.1  2003/05/07 11:14:08  mt
  * added OpenBSD pf-nat transparent proxy support
  * fixed to use hls->retr instead of a static retry counter
