@@ -1,5 +1,5 @@
 /*
- * $Id: com-socket.h,v 1.5 2002/05/02 13:01:32 mt Exp $
+ * $Id: com-socket.h,v 1.5.2.1 2003/05/07 11:13:34 mt Exp $
  *
  * Header for common functions for TCP/IP sockets
  *
@@ -88,6 +88,7 @@ typedef struct hls_t {
 	int       sock;		/* The corresponding socket	*/
 	int       kill;		/* 1=kill socket after send	*/
 	int       ernr;		/* socket i/o error number	*/
+	int       retr;		/* recv i/o retry counter	*/
 	int       flag;		/* Flag for send() (e.g. OOB)	*/
 	int       more;		/* 1=read more to complete line	*/
 	u_int32_t addr;		/* Peer's address (host order)	*/
@@ -151,6 +152,9 @@ int        getfqdomainname(char *fqdomain, size_t n);
 
 /* ------------------------------------------------------------
  * $Log: com-socket.h,v $
+ * Revision 1.5.2.1  2003/05/07 11:13:34  mt
+ * added hls->retr -- recv i/o retry counter
+ *
  * Revision 1.5  2002/05/02 13:01:32  mt
  * merged with v1.8.2.2
  *
