@@ -1,5 +1,5 @@
 /*
- * $Id: com-syslog.c,v 1.6 2002/05/02 13:01:58 mt Exp $
+ * $Id: com-syslog.c,v 1.6.2.1 2003/05/07 11:14:34 mt Exp $
  *
  * Common file/syslog logging functions
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: com-syslog.c,v 1.6 2002/05/02 13:01:58 mt Exp $";
+static char rcsid[] = "$Id: com-syslog.c,v 1.6.2.1 2003/05/07 11:14:34 mt Exp $";
 #endif
 
 #include <config.h>
@@ -221,7 +221,7 @@ void syslog_open(char *name, char *level)
 		return;
 	}
 
-	if (NULL != log_name && NULL != name) {
+	if (NULL != log_name && NULL != name && '\0' != name[0]) {
 		/*
 		** this is a reopen - write a message with
 		** the new log destination into the old one
@@ -232,7 +232,7 @@ void syslog_open(char *name, char *level)
 	}
 
 	syslog_close();
-	if (NULL == name) {
+	if (NULL == name || '\0' == name[0]) {
 		/*
 		** hmm... it was a close...
 		*/
@@ -663,6 +663,9 @@ void syslog_close(void)
 
 /* ------------------------------------------------------------
  * $Log: com-syslog.c,v $
+ * Revision 1.6.2.1  2003/05/07 11:14:34  mt
+ * added check for empty name in log_open
+ *
  * Revision 1.6  2002/05/02 13:01:58  mt
  * merged with v1.8.2.2
  *
