@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-client.c,v 1.9.2.1 2003/05/07 11:11:33 mt Exp $
+ * $Id: ftp-client.c,v 1.9.2.3 2005/01/11 13:00:01 mt Exp $
  *
  * Functions for the FTP Proxy client handling
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-client.c,v 1.9.2.1 2003/05/07 11:11:33 mt Exp $";
+static char rcsid[] = "$Id: ftp-client.c,v 1.9.2.3 2005/01/11 13:00:01 mt Exp $";
 #endif
 
 #include <config.h>
@@ -1338,16 +1338,54 @@ int client_setup(char *pwd)
 	}
 
 	/*
-	** dont allow empty or invalid names...
+	** don't allow empty or invalid names...
 	*/
-	if(NULL != who && who[0]) {
+	if(NULL != who && '\0' != who[0]) {
 		char *ptr;
-		for(ptr=who; ptr[0]; ptr++)
-		if( !(isalnum(ptr[0]) || '-'  == ptr[0]  || '_'  == ptr[0])) {
-				syslog_write(U_ERR, "invalid user naem");
-			return -1;
+#if defined(HAVE_REGEX)
+		char *rule;
+		void *preg = NULL;
+
+		rule = config_str(NULL, "UserNameRule",
+		       "^[[:alnum:]]+([%20@/\\._-][[:alnum:]]+)*$");
+		       
+		syslog_write(T_DBG, "compiling UserNameRule: '%.1024s'", rule);
+		if(NULL == (ptr = cmds_reg_comp(&preg, rule))) {
+		    return -1;
 		}
+		syslog_write(T_DBG, "DeHTMLized UserNameRule: '%.1024s'", ptr);
+
+		ptr = cmds_reg_exec(preg, who);
+		if(NULL != ptr) {
+			syslog_write(U_WRN, "invalid user name '%.128s'%s: %s",
+			             who, (strlen(who)>128 ? "..." : ""), ptr);
+			cmds_reg_comp(&preg, NULL); /* free regex ptr */
+			return -1;
+		} else {
+			cmds_reg_comp(&preg, NULL); /* free regex ptr */
+		}
+#else
+		/*
+		** Simplified "emulation" of the above regex:
+		*/
+		if( !(isalnum(who[0]) && isalnum(who[strlen(who)-1]))) {
+		    syslog_write(U_ERR, "invalid user name '%.128s'%s",
+		                 who, (strlen(who)>128 ? "..." : ""));
+		    return 1;
+		}
+		for(ptr=who+1; *ptr; ptr++) {
+		    if( !(isalnum(*ptr) ||
+		           ' ' == *ptr  || '@' == *ptr || '/' == *ptr ||
+		           '.' == *ptr  || '_' == *ptr || '-' == *ptr))
+		    {
+			syslog_write(U_ERR, "invalid user name '%.128s'%s",
+			             who, (strlen(who)>128 ? "..." : ""));
+			return -1;
+		    }
+		}
+#endif
 	} else {
+		/* HUH ?! */
 		syslog_write(U_ERR, "empty user name");
 		return -1;
 	}
@@ -1569,6 +1607,14 @@ static int client_setup_file(CONTEXT *ctx, char *who)
 
 /* ------------------------------------------------------------
  * $Log: ftp-client.c,v $
+ * Revision 1.9.2.3  2005/01/11 13:00:01  mt
+ * fixed default UserNameRule regexp rejecting user
+ * names where the 3. character is not alphanumeric
+ *
+ * Revision 1.9.2.2  2004/03/22 12:40:13  mt
+ * implemented a UserNameRule option allowing a regex
+ * based override of the builtin user name checks
+ *
  * Revision 1.9.2.1  2003/05/07 11:11:33  mt
  * removed broken ABOR sending on error while srv_data xfer still runs
  * moved user config-profile reading from ftp-ldap to client_setup_file()
