@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-cmds.c,v 1.10.2.1 2003/05/07 11:10:45 mt Exp $
+ * $Id: ftp-cmds.c,v 1.10.2.2 2004/03/10 16:00:49 mt Exp $
  *
  * FTP Proxy command handling
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-cmds.c,v 1.10.2.1 2003/05/07 11:10:45 mt Exp $";
+static char rcsid[] = "$Id: ftp-cmds.c,v 1.10.2.2 2004/03/10 16:00:49 mt Exp $";
 #endif
 
 #include <config.h>
@@ -164,6 +164,7 @@ static CMD cmdlist[] = {
 	{ "XRMD", cmds_pthr, REST },
 	{ "XPWD", cmds_pthr, REST },
 	{ "XCUP", cmds_pthr, REST },
+	{ "RCMD", cmds_pthr, REST },
 #if defined(ENABLE_SSL) /* <!-- SSL --> */
 	{ "AUTH", cmds_auth, REST },	/* Only needed for SSL	*/
 #endif /* <!-- /SSL --> */
@@ -1606,6 +1607,9 @@ static int parse_magic_dest(CONTEXT *ctx, char *dest)
 
 /* ------------------------------------------------------------
  * $Log: ftp-cmds.c,v $
+ * Revision 1.10.2.2  2004/03/10 16:00:49  mt
+ * added support for RCMD command (pass-through)
+ *
  * Revision 1.10.2.1  2003/05/07 11:10:45  mt
  * - fixed user magic parsing to allow emal-address in
  *   username while @ is used as user magic separator
