@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-ldap.c,v 1.7.2.2 2003/05/11 20:22:17 mt Exp $
+ * $Id: ftp-ldap.c,v 1.7.2.3 2004/03/10 16:07:13 mt Exp $
  *
  * FTP Proxy LDAP interface handling
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-ldap.c,v 1.7.2.2 2003/05/11 20:22:17 mt Exp $";
+static char rcsid[] = "$Id: ftp-ldap.c,v 1.7.2.3 2004/03/10 16:07:13 mt Exp $";
 #endif
 
 #include <config.h>
@@ -258,7 +258,7 @@ static char* prep_bind_auto(LDAP *ld, char *flt, char *base, char *peer)
 {
 	LDAPMessage *result, *e;
 	char        *attrs[] = {0, 0};
-	char        *bind_dn, *p;
+	char        *bind_dn, *p, *d;
 	int          err;
 
 	if(NULL == base || '\0' == base[0]) {
@@ -266,9 +266,14 @@ static char* prep_bind_auto(LDAP *ld, char *flt, char *base, char *peer)
 	}
 
 	/*
-	** pre-bind anonymously
+	** pre-bind (anonymously)
 	*/
-	err = ldap_simple_bind_s(ld, 0, 0);
+	if((d = config_str(NULL, "LDAPPreBindDN", NULL)) &&
+	   (p = config_str(NULL, "LDAPPreBindPW", NULL))) {
+	    err = ldap_simple_bind_s(ld, d, p);
+	} else {
+	    err = ldap_simple_bind_s(ld, 0, 0);
+	}
 	if(LDAP_SUCCESS != err) {
 		syslog_write(T_ERR,
 		       "can't bind LDAP anonymously for %s: %.512s",
@@ -1015,13 +1020,17 @@ static int  ldap_exists(LDAP *ld, LDAPMessage *e, char *attr,
 
 /* ------------------------------------------------------------
  * $Log: ftp-ldap.c,v $
+ * Revision 1.7.2.3  2004/03/10 16:07:13  mt
+ * added LDAPPreBindDN/LDAPPreBindPW options usable
+ * instead of anonymous bind while LDAPBindDN=auto
+ *
  * Revision 1.7.2.2  2003/05/11 20:22:17  mt
  * simplyfied ldap version handling
  *
  * Revision 1.7.2.1  2003/05/07 11:10:00  mt
- * - moved user profile-config reading to ftp-client.c
- * - added LDAP_VERSION handling with LDAPv3 default
- * - improved user-auth to support auth via ldap-bind
+ * moved user profile-config reading to ftp-client.c
+ * added LDAP_VERSION handling with LDAPv3 default
+ * improved user-auth to support auth via ldap-bind
  *
  * Revision 1.7  2002/05/02 13:17:12  mt
  * implemented simple (ldap based) user auth
