@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-ldap.h,v 1.4 2002/05/02 13:17:12 mt Exp $
+ * $Id: ftp-ldap.h,v 1.4.2.1 2003/05/07 11:09:27 mt Exp $
  *
  * Header for FTP Proxy LDAP interface handling
  *
@@ -41,7 +41,7 @@
 #    define  PASS_MIN_LEN	5
 #endif
 
-int  ldap_setup_user(CONTEXT *ctx, char *pwd);
+int  ldap_setup_user(CONTEXT *ctx, char *who, char *pwd);
 
 
 /* ------------------------------------------------------------ */
@@ -50,6 +50,11 @@ int  ldap_setup_user(CONTEXT *ctx, char *pwd);
 
 /* ------------------------------------------------------------
  * $Log: ftp-ldap.h,v $
+ * Revision 1.4.2.1  2003/05/07 11:09:27  mt
+ * - moved user profile-config reading to ftp-client.c
+ * - added LDAP_VERSION handling with LDAPv3 default
+ * - improved user-auth to support auth via ldap-bind
+ *
  * Revision 1.4  2002/05/02 13:17:12  mt
  * implemented simple (ldap based) user auth
  *
