@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-main.c,v 1.6 2002/01/14 19:24:46 mt Exp $
+ * $Id: ftp-main.c,v 1.6.6.1 2003/05/07 11:08:55 mt Exp $
  *
  * Main program of the FTP Proxy
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-main.c,v 1.6 2002/01/14 19:24:46 mt Exp $";
+static char rcsid[] = "$Id: ftp-main.c,v 1.6.6.1 2003/05/07 11:08:55 mt Exp $";
 #endif
 
 #include <config.h>
@@ -243,11 +243,11 @@ int main(int argc, char *argv[])
 			detach = 0;	/* Don't detach (e.g. AIX) */
 			break;
 		case 'f':
-			cfg_file = optarg;
+			cfg_file = misc_strtrim(optarg);
 			break;
 #if defined(COMPILE_DEBUG)
 		case 'v':
-			debug_init(atoi(optarg), DEBUG_FILE);
+			debug_init(atoi(misc_strtrim(optarg)), DEBUG_FILE);
 			break;
 #endif
 		case 'V':
@@ -387,6 +387,9 @@ int main(int argc, char *argv[])
 
 /* ------------------------------------------------------------
  * $Log: ftp-main.c,v $
+ * Revision 1.6.6.1  2003/05/07 11:08:55  mt
+ * added strtrim arround optarg
+ *
  * Revision 1.6  2002/01/14 19:24:46  mt
  * reordered config reading, chroot and syslog opening
  * added config_filename function for runtime queries
